Products  What's New  Explore SAP  Products  What's New  Explore SAP
  * [Home](https://help.sap.com/docs/)
  * [SAP LeanIX](https://help.sap.com/docs/leanix)
  * …
  * [Fact Sheet Modeling Guidelines](https://help.sap.com/docs/leanix/ea/fact-sheet-modeling-guidelines)
  * Organization Modeling Guidelines
